@@ -50,116 +50,123 @@
 
 void CasseBrique::main()
 {
-  _Fenetre.LancerBoucle();
+    if (_CreateOk)
+    {
+        _Fenetre.LancerBoucle();
+    }
 }
 
 
-CasseBrique::CasseBrique(): MOGL_Action(), _Fenetre("Briquolo"), _Tableau(NULL),
-                            _Pause(false), _MenuBase(NULL), _EnumAction(MENU)
+CasseBrique::CasseBrique(): MOGL_Action(), _Fenetre(("BRIQUOLO v"+Constante::GetVersion()).c_str()), _Tableau(NULL),
+                            _Pause(false), _MenuBase(NULL), _EnumAction(MENU), _CreateOk(false)
 {
-  cout<<("BRIQUOLO v"+Constante::GetVersion()).c_str()<<endl;
-  string fichier(Constante::GetLocalDir());
+    string fichier(Constante::GetLocalDir());
 #ifdef WIN32
-  _mkdir(fichier.c_str());
+    _mkdir(fichier.c_str());
 #else
-  mkdir(fichier.c_str(), 0775);
+    mkdir(fichier.c_str(), 0775);
 #endif
 
-  fichier+=Constante::GetTableauDir();
+    fichier+=Constante::GetTableauDir();
 #ifdef WIN32
-  _mkdir(fichier.c_str());
+    _mkdir(fichier.c_str());
 #else
-  mkdir(fichier.c_str(), 0775);
+    mkdir(fichier.c_str(), 0775);
 #endif
-  Option::Charger();
-  _Fenetre.SetFullscreen(Option::Fullscreen.GetValeur());
-  _Fenetre.SetMode(Option::ResolutionX.GetValeur(), Option::ResolutionY.GetValeur());
-  _Fenetre.Initialiser();
-  Option::ResolutionX.SetValeur(_Fenetre.GetResolutionX());
-  Option::ResolutionY.SetValeur(_Fenetre.GetResolutionY());
+    Option::Charger();
+    _Fenetre.SetFullscreen(Option::Fullscreen.GetValeur());
+    _Fenetre.SetMode(Option::ResolutionX.GetValeur(), Option::ResolutionY.GetValeur());
+    if (_Fenetre.Initialiser())
+    {
+        Option::ResolutionX.SetValeur(_Fenetre.GetResolutionX());
+        Option::ResolutionY.SetValeur(_Fenetre.GetResolutionY());
 
-  _Fenetre.DefinirRepetitionTouche(1,1);
-  MOGL_Temps::SetMaxFPS(Option::MaxFPS.GetValeur());
-  _Fenetre.SetGrabCurseur(false);
-  _Fenetre.SetCacherCurseur(false);
-  Son::Initialiser();
-  BibliothequeSon::Initialiser();
-  Texture::ChargerTextures();
-  MOGL_Bibliotheque::GetSingleton()->ReinitialiserSurChangementModeFenetre(&_Fenetre);
-  _MenuPrincipal=new MenuPrincipal(&_Fenetre);
-  _MenuPrincipal->SetActivation(true);
-  _Fenetre.AjouterInterface(_MenuPrincipal);
-  _MenuPrincipal->BoutonEditeur->Activation.Connecter(this, &CasseBrique::_OnEditer);
-  _MenuPrincipal->BoutonQuitter->Activation.Connecter(this, &CasseBrique::_OnQuitter);
-  _MenuPrincipal->Ok->Activation.Connecter(this, &CasseBrique::_OnCommencerJeu);
+        _Fenetre.DefinirRepetitionTouche(1,1);
+        MOGL_Temps::SetMaxFPS(Option::MaxFPS.GetValeur());
+        _Fenetre.SetGrabCurseur(false);
+        _Fenetre.SetCacherCurseur(false);
+        if (Son::Initialiser())
+        {
+            BibliothequeSon::Initialiser();
+            Texture::ChargerTextures();
+            MOGL_Bibliotheque::GetSingleton()->ReinitialiserSurChangementModeFenetre(&_Fenetre);
+            _MenuPrincipal=new MenuPrincipal(&_Fenetre);
+            _MenuPrincipal->SetActivation(true);
+            _Fenetre.AjouterInterface(_MenuPrincipal);
+            _MenuPrincipal->BoutonEditeur->Activation.Connecter(this, &CasseBrique::_OnEditer);
+            _MenuPrincipal->BoutonQuitter->Activation.Connecter(this, &CasseBrique::_OnQuitter);
+            _MenuPrincipal->Ok->Activation.Connecter(this, &CasseBrique::_OnCommencerJeu);
 
-  _RectangleFond=new MOGL_Polygone();
-  srand(SDL_GetTicks());
-  for(int i=0; i<4; i++)
-  {
-    r[i]=2*M_PI*(rand()/static_cast<float>(RAND_MAX));
-    g[i]=2*M_PI*(rand()/static_cast<float>(RAND_MAX));
-    b[i]=2*M_PI*(rand()/static_cast<float>(RAND_MAX));
-  }
-  MOGL_Struct_Couleur coul;
-  coul.r=0;
-  coul.g=0;
-  coul.b=0;
-  coul.a=1;
-  _RectangleFond->AjouterPoint(0,0,coul);
-  _RectangleFond->AjouterPoint(0,_Fenetre.GetResolutionY(),coul);
-  _RectangleFond->AjouterPoint(_Fenetre.GetResolutionX(), _Fenetre.GetResolutionY(),coul);
-  _RectangleFond->AjouterPoint(_Fenetre.GetResolutionX(),0,coul);
-  _Facade.AjouterElement(_RectangleFond);
-  MOGL_Struct_Couleur coulTexte;
-  coulTexte.r=0;
-  coulTexte.g=0;
-  coulTexte.b=1;
-  coulTexte.a=0.5;
+            _RectangleFond=new MOGL_Polygone();
+            srand(SDL_GetTicks());
+            for(int i=0; i<4; i++)
+            {
+                r[i]=2*M_PI*(rand()/static_cast<float>(RAND_MAX));
+                g[i]=2*M_PI*(rand()/static_cast<float>(RAND_MAX));
+                b[i]=2*M_PI*(rand()/static_cast<float>(RAND_MAX));
+            }
+            MOGL_Struct_Couleur coul;
+            coul.r=0;
+            coul.g=0;
+            coul.b=0;
+            coul.a=1;
+            _RectangleFond->AjouterPoint(0,0,coul);
+            _RectangleFond->AjouterPoint(0,_Fenetre.GetResolutionY(),coul);
+            _RectangleFond->AjouterPoint(_Fenetre.GetResolutionX(), _Fenetre.GetResolutionY(),coul);
+            _RectangleFond->AjouterPoint(_Fenetre.GetResolutionX(),0,coul);
+            _Facade.AjouterElement(_RectangleFond);
+            MOGL_Struct_Couleur coulTexte;
+            coulTexte.r=0;
+            coulTexte.g=0;
+            coulTexte.b=1;
+            coulTexte.a=0.5;
 
-  MOGL_Struct_Couleur coulFond;
-  coulFond.r=1;
-  coulFond.g=1;
-  coulFond.b=1;
-  coulFond.a=0.7f;
+            MOGL_Struct_Couleur coulFond;
+            coulFond.r=1;
+            coulFond.g=1;
+            coulFond.b=1;
+            coulFond.a=0.7f;
 
-  _TexteFPS.SetCouleurTexte(coulTexte);
-  _TexteFPS.SetCouleurFond(coulFond);
+            _TexteFPS.SetCouleurTexte(coulTexte);
+            _TexteFPS.SetCouleurFond(coulFond);
 
-  _TexteFPS.SetCacher(!Option::AfficherFPS.GetValeur());
-  _Facade.AjouterElement(&_TexteFPS);
+            _TexteFPS.SetCacher(!Option::AfficherFPS.GetValeur());
+            _Facade.AjouterElement(&_TexteFPS);
 
-  _ImagePlateau=new MOGL_ImageFacade;
-  _ImagePlateau->ChargerPNG((Constante::GetGlobalDir()+Constante::GetDataDir()+"/imageplateau.png").c_str());
-  _ImagePlateau->SetPosition(0,0);
-  _Facade.AjouterElement(_ImagePlateau);
+            _ImagePlateau=new MOGL_ImageFacade;
+            _ImagePlateau->ChargerPNG((Constante::GetGlobalDir()+Constante::GetDataDir()+"/imageplateau.png").c_str());
+            _ImagePlateau->SetPosition(0,0);
+            _Facade.AjouterElement(_ImagePlateau);
 
-  MOGL_Struct_Couleur coulTexteNombreVie;
-  coulTexteNombreVie.r=0;
-  coulTexteNombreVie.g=0;
-  coulTexteNombreVie.b=0;
-  coulTexteNombreVie.a=1;
-  _TexteNombreVie.SetCouleurTexte(coulTexteNombreVie);
-  _PoliceVie=new MOGL_PoliceBitmap();
-  _PoliceVie->Charger((Constante::GetGlobalDir()+Constante::GetDataDir()+"/vie.ftx").c_str());
-  _TexteNombreVie.SetPolice(_PoliceVie);
-  _TexteNombreVie.SetPosition(100,0);
-  _Facade.AjouterElement(&_TexteNombreVie);
+            MOGL_Struct_Couleur coulTexteNombreVie;
+            coulTexteNombreVie.r=0;
+            coulTexteNombreVie.g=0;
+            coulTexteNombreVie.b=0;
+            coulTexteNombreVie.a=1;
+            _TexteNombreVie.SetCouleurTexte(coulTexteNombreVie);
+            _PoliceVie=new MOGL_PoliceBitmap();
+            _PoliceVie->Charger((Constante::GetGlobalDir()+Constante::GetDataDir()+"/vie.ftx").c_str());
+            _TexteNombreVie.SetPolice(_PoliceVie);
+            _TexteNombreVie.SetPosition(100,0);
+            _Facade.AjouterElement(&_TexteNombreVie);
 
-  _ImagePlateau->SetCacher(true);
-  _TexteNombreVie.SetCacher(true);
+            _ImagePlateau->SetCacher(true);
+            _TexteNombreVie.SetCacher(true);
 
-  _Fenetre.AjouterInterface(&_Facade);
+            _Fenetre.AjouterInterface(&_Facade);
 
-  _Fenetre.Idle.Connecter(this,&CasseBrique::_Idle);
-  _Fenetre.KeyDown.Connecter(this,&CasseBrique::_ClavierDown);
-  _Fenetre.KeyUp.Connecter(this,&CasseBrique::_ClavierUp);
-  _Fenetre.MouseMove.Connecter(this,&CasseBrique::_DeplacementSouris);
-  _Fenetre.MouseButtonUp.Connecter(this,&CasseBrique::_BoutonSourisUp);
-  _Fenetre.MouseButtonDown.Connecter(this,&CasseBrique::_BoutonSourisDown);
-  _Fenetre.Destruction.Connecter(this,&CasseBrique::_OnDestruction);
-  _Fenetre.ChangementMode.Connecter(this, &CasseBrique::_OnChangementResolution);
+            _Fenetre.Idle.Connecter(this,&CasseBrique::_Idle);
+            _Fenetre.KeyDown.Connecter(this,&CasseBrique::_ClavierDown);
+            _Fenetre.KeyUp.Connecter(this,&CasseBrique::_ClavierUp);
+            _Fenetre.MouseMove.Connecter(this,&CasseBrique::_DeplacementSouris);
+            _Fenetre.MouseButtonUp.Connecter(this,&CasseBrique::_BoutonSourisUp);
+            _Fenetre.MouseButtonDown.Connecter(this,&CasseBrique::_BoutonSourisDown);
+            _Fenetre.Destruction.Connecter(this,&CasseBrique::_OnDestruction);
+            _Fenetre.ChangementMode.Connecter(this, &CasseBrique::_OnChangementResolution);
 
+            _CreateOk = true;
+        }
+    }
 }
 
 CasseBrique::~CasseBrique()
@@ -169,7 +176,7 @@ CasseBrique::~CasseBrique()
     _Tableau->EffacerTousElementTableau();
     delete _Tableau;
   }
-        
+
   if (_MenuBase!=NULL)
   {
     delete _MenuBase;
@@ -466,7 +473,7 @@ void CasseBrique::_OnCommencerJeu()
     _Fenetre.AjouterInterface(_MenuBase);
     _MenuBase->FinMenuBase.Connecter(this, & CasseBrique::_OnFinPause);
     _EnumAction=JEU;
-    
+
     _MenuPrincipal->PanneauOption->SetActivation(false);
     _MenuPrincipal->SetActivation(false);
   }
@@ -483,7 +490,7 @@ void CasseBrique::_OnEditer()
   _Tableau = new TableauEditeur(&_Fenetre);
   _FinJeu=false;
   _Tableau->Activer(true);
-  
+
   _MenuBase=new MenuEditeur(&_Fenetre);
 
   ((MenuEditeur*)_MenuBase)->_PanneauSauvegarder->DemanderEnregistrement.Connecter(this, &CasseBrique::_OnSauvegarder);
