@@ -19,10 +19,11 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  *****************************************************************************/
+#include "../I18n.h"
 #include "MOGL_EnsembleObjet.h"
 #include "MOGL_Armature.h"
 #include "MOGL_Peau.h"
-//#include 
+//#include
 #include <stdio.h>
 
 //#include <mmsystem.h>
@@ -50,22 +51,22 @@ bool MOGL_EnsembleObjet::Charger(char * p_NomFichier, const MOGL_GestionnaireTex
   vector <MOGL_Noeud *> TabObjet;
   _Noeud=new MOGL_Noeud;
   TabObjet.push_back(_Noeud);
-        
+
   ifstream Fichier(p_NomFichier);
-        
+
   if (Fichier.fail())
   {
         return false;
   }
 
   do
-  {     
+  {
         Fichier.getline(chaine,200);
 
         if (!strncmp(chaine,"Objet",5))
         {
           // C'est un objet avec des faces
-                        
+
 
           if (!debut)
           {
@@ -106,7 +107,7 @@ bool MOGL_EnsembleObjet::Charger(char * p_NomFichier, const MOGL_GestionnaireTex
         if (!strncmp(chaine,"Noeud",5))
         {
           // C'est un simple noeud sans faces
-                        
+
 
           if (!debut)
           {
@@ -178,7 +179,7 @@ bool MOGL_EnsembleObjet::Charger(char * p_NomFichier, const MOGL_GestionnaireTex
           strncpy(temp,chaine+i,j-i);
           temp[j-i]=0;
           Texture=p_GM.GetTexture(temp);
-                        
+
         }
 
         if (!strncmp(chaine,"Vertex",6))
@@ -197,7 +198,7 @@ bool MOGL_EnsembleObjet::Charger(char * p_NomFichier, const MOGL_GestionnaireTex
           while(chaine[i]!='Z') i++;
           i+=2;
           sscanf(chaine+i,"%f",&z);
-                        
+
           while(chaine[i]!='U') i++;
           i+=2;
           sscanf(chaine+i,"%f",&u);
@@ -238,7 +239,7 @@ bool MOGL_EnsembleObjet::Charger(char * p_NomFichier, const MOGL_GestionnaireTex
   }
   _MapObjet[NomCourant]=ObjetCourant;
   TabObjet[NiveauCourant-1]->AjouterElement(ObjetCourant);
-        
+
   return true;
 }
 
@@ -262,28 +263,29 @@ bool MOGL_EnsembleObjet::ChargerArmaturePeau(char * p_NomFichier, const MOGL_Ges
   MOGL_TrianglePeau Triangle;
   string NomCourant,NomRef;
   unsigned int NiveauCourant=0;
-  MOGL_Struct_Vecteur Rotation, Translation;
+  MOGL_Struct_Vecteur Rotation = {0,0,0};
+  MOGL_Struct_Vecteur Translation = {0,0,0};
 
   vector <MOGL_Noeud *> TabObjet;
 
   bool peauRencontre=false;
-  
-  
+
+
   // Ici le _Noeud de base est un MOGL_Peau
   _Noeud=new MOGL_Peau;
 
   TabObjet.push_back(_Noeud);
 
-        
+
   ifstream Fichier(p_NomFichier);
-        
+
   if (Fichier.fail())
   {
         return false;
   }
 
   do
-  {     
+  {
         Fichier.getline(chaine,200);
 
         if (!strncmp(chaine,"Objet",5))
@@ -294,7 +296,7 @@ bool MOGL_EnsembleObjet::ChargerArmaturePeau(char * p_NomFichier, const MOGL_Ges
                 {
                   static_cast<MOGL_Peau *>(ObjetCourant)->AjouterTriangle(Triangle);
                 }
-                
+
                 index_point=0;
                 _MapObjet[NomCourant]=ObjetCourant;
                 if (type_objet==ARMATURE)
@@ -360,7 +362,7 @@ bool MOGL_EnsembleObjet::ChargerArmaturePeau(char * p_NomFichier, const MOGL_Ges
           }
           else
           {
-                cerr<<"Le fichier contient deux objets de type peau, ce qui n'st pas possible !"<<endl;
+                cerr<<"The file contains two skin objects, which is impossinble!"<<endl;
                 return false;
           }
         }
@@ -383,7 +385,7 @@ bool MOGL_EnsembleObjet::ChargerArmaturePeau(char * p_NomFichier, const MOGL_Ges
           while(chaine[i]!='Y') i++;
           i+=2;
           sscanf(chaine+i,"%f",&y);
-                        
+
           while(chaine[i]!='Z') i++;
           i+=2;
           sscanf(chaine+i,"%f",&z);
@@ -404,7 +406,7 @@ bool MOGL_EnsembleObjet::ChargerArmaturePeau(char * p_NomFichier, const MOGL_Ges
           while(chaine[i]!='Y') i++;
           i+=2;
           sscanf(chaine+i,"%f",&y);
-                        
+
           while(chaine[i]!='Z') i++;
           i+=2;
           sscanf(chaine+i,"%f",&z);
@@ -460,7 +462,7 @@ bool MOGL_EnsembleObjet::ChargerArmaturePeau(char * p_NomFichier, const MOGL_Ges
                 }
                 case NOEUD :
                 {
-                  cerr<<"Un Noeud ne peut pas avoir de points !"<<endl;
+                  cerr<<"A node can't contain points!"<<endl;
                 }
           }
         }
@@ -492,7 +494,7 @@ bool MOGL_EnsembleObjet::ChargerArmaturePeau(char * p_NomFichier, const MOGL_Ges
           Texture=p_GM.GetTexture(temp);
           if (Texture==NULL)
           {
-                cerr<<"Texture non trouve"<<endl;
+                cerr<<"Texture not found"<<endl;
           }
           Triangle.SetTexture(Texture);
         }
@@ -505,20 +507,20 @@ bool MOGL_EnsembleObjet::ChargerArmaturePeau(char * p_NomFichier, const MOGL_Ges
           while(chaine[i]!='P') i++;
           i++;
           int indice_ref;
-          
+
           if (chaine[i]=='E')
           {
                 // C'est une rfrence externe
                 i+=2;
                 sscanf(chaine+i,"%i",&indice_ref);
-                
+
                 while(chaine[i]!='"') i++;
                 i++;
                 j=i;
                 while(chaine[j]!='"') j++;
                 strncpy(temp,chaine+i,j-i);
                 temp[j-i]=0;
-                
+
                 Triangle.SetPoint(index_point, (MOGL_Armature *)_MapObjet[temp], indice_ref-1);
           }
           else
@@ -526,10 +528,10 @@ bool MOGL_EnsembleObjet::ChargerArmaturePeau(char * p_NomFichier, const MOGL_Ges
                 // C'est une rfrence interne
                 i+=2;
                 sscanf(chaine+i,"%i",&indice_ref);
-                
+
                 Triangle.SetPoint(index_point, indice_ref-1);
           }
-          
+
           i+=2;
           sscanf(chaine+i,"%i",&indicePoint);
 
@@ -550,15 +552,15 @@ bool MOGL_EnsembleObjet::ChargerArmaturePeau(char * p_NomFichier, const MOGL_Ges
 
           index_point++;
         }
-          
+
   } while(!Fichier.eof());
 
   if (!peauRencontre)
   {
-        cerr<<"Le fichier ne contient pas de peau ! Ce n'est pas possible !"<<endl;
+        cerr<<"The file doesn't contain a skin! That's impossible!"<<endl;
         return false;
   }
-  
+
   if (type_objet==PEAU && !PremiereFace)
   {
         static_cast<MOGL_Peau *>(ObjetCourant)->AjouterTriangle(Triangle);
@@ -578,8 +580,8 @@ bool MOGL_EnsembleObjet::ChargerArmaturePeau(char * p_NomFichier, const MOGL_Ges
         _MapObjet[NomCourant]=ObjetCourant;
         TabObjet[NiveauCourant-1]->AjouterElement(ObjetCourant);
   }
-  
-        
+
+
   return true;
 }
 
@@ -593,21 +595,21 @@ bool MOGL_EnsembleObjet::ChargerAnimation(char * p_NomFichier, char * p_NomAnima
   float t,x,y,z;
   int index_point=0;
   bool debut=true;
-  MOGL_Noeud * NoeudCourant;    
+  MOGL_Noeud * NoeudCourant;
   MOGL_Animation * AnimationCourant=NULL;
   MOGL_GroupeAnimation * GroupeAnimation=new MOGL_GroupeAnimation;
   string NomCourant;
 
-        
+
   ifstream Fichier(p_NomFichier);
-        
+
   if (Fichier.fail())
   {
         return false;
   }
 
   do
-  {     
+  {
         Fichier.getline(chaine,200);
 
         if (!strncmp(chaine,"Nom",3))
@@ -622,7 +624,7 @@ bool MOGL_EnsembleObjet::ChargerAnimation(char * p_NomFichier, char * p_NomAnima
           {
                 debut=false;
           }
-                        
+
           //PremiereFace=true;
           i=0;
           while(chaine[i]!='"') i++;
@@ -654,7 +656,7 @@ bool MOGL_EnsembleObjet::ChargerAnimation(char * p_NomFichier, char * p_NomAnima
           while(chaine[i]!='Y') i++;
           i+=2;
           sscanf(chaine+i,"%f",&y);
-                        
+
           while(chaine[i]!='Z') i++;
           i+=2;
           sscanf(chaine+i,"%f",&z);
@@ -684,7 +686,7 @@ bool MOGL_EnsembleObjet::ChargerAnimation(char * p_NomFichier, char * p_NomAnima
           while(chaine[i]!='Y') i++;
           i+=2;
           sscanf(chaine+i,"%f",&y);
-                        
+
           while(chaine[i]!='Z') i++;
           i+=2;
           sscanf(chaine+i,"%f",&z);
@@ -702,7 +704,7 @@ bool MOGL_EnsembleObjet::ChargerAnimation(char * p_NomFichier, char * p_NomAnima
   GroupeAnimation->AjouterAnimation(AnimationCourant);
 
   _MapGroupeAnimation[p_NomAnimation]=GroupeAnimation;
-        
+
   return true;
 }
 
@@ -716,7 +718,7 @@ void MOGL_EnsembleObjet::DebuterAnimation(char * p_NomAnim)
         itGAnim->second->SetUniteTemps(0.5);
         itGAnim->second->Initialiser();
   }
-  
+
 }
 
 void MOGL_EnsembleObjet::Animer()
