@@ -128,16 +128,16 @@ class MOGL_Fenetre
     SDL_Surface * _CreerFenetre(unsigned int & p_Bpp, unsigned int p_Flags);
 
   public :
-    MOGL_Fenetre(char * p_Titre=NULL);
+    MOGL_Fenetre(const char * p_Titre=NULL);
     ~MOGL_Fenetre();
-                
+
     /**
        Permet de dfinir la rsolution de la fentre
        @param p_ResolutionX : rsolution en X de la fentre
        @param p_ResolutionY : rsolution en Y de la fentre
        @param p_Fullscreen : indique si la fentre doit tre plein cran ou non.
        @return <i>true</i> si il n'y a pas eu de problme, <i>false</i> sinon. Un problme peut intervenir seuleument s'il
-               s'agit d'un changement de mode alors que la fen^tre existe 
+               s'agit d'un changement de mode alors que la fen^tre existe
     */
     bool SetMode(int p_ResolutionX, int p_ResolutionY, bool p_Fullscreen);
 
@@ -169,7 +169,7 @@ class MOGL_Fenetre
     int GetBPP() const;
 
     /**
-       Permet de dfinir le titre de la fentre. Le titre n'est affich que lorsque la fenetre n'est pas en plein cran 
+       Permet de dfinir le titre de la fentre. Le titre n'est affich que lorsque la fenetre n'est pas en plein cran
        (@sa SetFullscreen()].
        @param p_Titre : titre de la fentre
     */
@@ -206,7 +206,7 @@ class MOGL_Fenetre
        Permet d'arreter la boucle init par LancerBoucle()
      */
     void Arreter();
-        
+
     /**
        Permet d'ajouter une interface  la fentre. Les interface reprsente des <i>contenus</i> lis  la fentre
        comme par exemple MOGL_Univers qui reprsente un univers 3D ou encore MOGL_Facade qui reprsente un affichage 2D.
@@ -218,7 +218,7 @@ class MOGL_Fenetre
        @sa AjouterInterface().
     */
     bool RetirerInterface(MOGL_Interface * p_Interface);
-        
+
 
     /**
        Permet d'infiquer  la fentre si elle peut garder le curseur.
@@ -238,21 +238,21 @@ class MOGL_Fenetre
     */
     void DefinirRepetitionTouche(int p_Delai, int p_Intervalle);
 
-    /** 
+    /**
      * Permet de prendre un screenshot au format BMP.
-     * 
+     *
      * @param p_NomFichier : nom du fichier de sauvegarde.
      *
      * @return <i>true</i> s'il n'y a pas eu d'erreur, <i>false</i> sinon.
      */
     bool ScreenshotBMP(char * p_NomFichier);
 
-    /** 
+    /**
      * Permet de prendre un screenshot au format BMP.
      * Le nom du fichier est ici dtermin de manire automatique,  partir du prefix fourni.
      * Le nom correspond au prfix indiqu qui est suivi d'un numro (le premier disponible,
      * de manire  ce que le fichier n'existe pas sur le disque), et de l'extension <i>.bmp</i>
-     * 
+     *
      * @param p_Prefix : prfix du nom du fichier
      *
      * @return <i>true</i> s'il n'y a pas eu d'erreur, <i>false</i> sinon.
