@@ -19,6 +19,7 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  *****************************************************************************/
+#include "../I18n.h"
 #include "MOGL_PoliceBitmap.h"
 #include <fstream>
 
@@ -36,7 +37,7 @@ bool MOGL_PoliceBitmap::Charger(const char * p_NomFichier)
     ifstream file(p_NomFichier, ios::in | ios::binary);
     if (file.fail())
     {
-        cerr<<"Erreur"<<endl;
+        cerr<<"Error"<<endl;
         return false;
     }
     _NbCaractere = _ReadUnsignedInt(file);
