@@ -307,137 +307,138 @@ string TableauBase::GetGroupeTableauDesc(const string & base, const string & dir
 
 list<string> TableauBase::GetListeGroupeTableau()
 {
-  set<string> preprocList;
-  list<string> liste;
-  _VectNomGroupe.clear();
+    set<string> preprocList;
+    list<string> liste;
+    _VectNomGroupe.clear();
 #ifdef WIN32
-  // Fichiers locaux
-  string rep(Constante::GetLocalDir());
-  rep+=Constante::GetTableauDir();
-  rep+='/';
+    // Fichiers locaux
+    string rep(Constante::GetLocalDir());
+    rep+=Constante::GetTableauDir();
+    rep+='/';
 
 
-  WIN32_FIND_DATA wData;
-  HANDLE listing;
-  listing = FindFirstFile((rep+"*").c_str(),    &wData);
-  do
-  {
-    string fichier=rep+wData.cFileName;
-    struct _stat stat_fic;
-    _stat(fichier.c_str(), &stat_fic);
-    if ((stat_fic.st_mode&_S_IFDIR)!=0 && _access(fichier.c_str(), 04)==0)
+    WIN32_FIND_DATA wData;
+    HANDLE listing;
+    listing = FindFirstFile((rep+"*").c_str(),    &wData);
+    do
     {
-      string le_fic(wData.cFileName);
-      if (le_fic!="" && le_fic != "." && le_fic != "..")
-      {
-        if (GetListeTableau(le_fic).size() != 0)
+        string fichier=rep+wData.cFileName;
+        struct _stat stat_fic;
+        _stat(fichier.c_str(), &stat_fic);
+        if ((stat_fic.st_mode&_S_IFDIR)!=0 && _access(fichier.c_str(), 04)==0)
         {
-          liste.push_back(GetGroupeTableauDesc(rep, le_fic));
-          _VectNomGroupe.push_back(le_fic);
+            string le_fic(wData.cFileName);
+            if (le_fic!="" && le_fic != "." && le_fic != "..")
+            {
+                if (GetListeTableau(le_fic).size() != 0)
+                {
+                    liste.push_back(GetGroupeTableauDesc(rep, le_fic));
+                    _VectNomGroupe.push_back(le_fic);
+                }
+            }
         }
-      }
-    }
-  } while((FindNextFile(listing, &wData)));
+    } while((FindNextFile(listing, &wData)));
 
-  // Fichiers globals
-  rep=Constante::GetGlobalDir();
-  rep+=Constante::GetTableauDir();
-  rep+='/';
-  listing = FindFirstFile((rep+"*").c_str(), &wData);
-  do
-  {
-    string fichier=rep+wData.cFileName;
-    struct _stat stat_fic;
-    _stat(fichier.c_str(), &stat_fic);
-    if ((stat_fic.st_mode&_S_IFDIR)!=0 && _access(fichier.c_str(), 04)==0)
+    // Fichiers globals
+    rep=Constante::GetGlobalDir();
+    rep+=Constante::GetTableauDir();
+    rep+='/';
+    listing = FindFirstFile((rep+"*").c_str(), &wData);
+    do
     {
-      string le_fic(wData.cFileName);
-      if (le_fic!="" && le_fic != "." && le_fic != "..")
-      {
-        if (GetListeTableau(le_fic).size() != 0)
+        string fichier=rep+wData.cFileName;
+        struct _stat stat_fic;
+        _stat(fichier.c_str(), &stat_fic);
+        if ((stat_fic.st_mode&_S_IFDIR)!=0 && _access(fichier.c_str(), 04)==0)
         {
-          liste.push_back(GetGroupeTableauDesc(rep, le_fic));
-          _VectNomGroupe.push_back(le_fic);
+            string le_fic(wData.cFileName);
+            if (le_fic!="" && le_fic != "." && le_fic != "..")
+            {
+                if (GetListeTableau(le_fic).size() != 0)
+                {
+                    liste.push_back(GetGroupeTableauDesc(rep, le_fic));
+                    _VectNomGroupe.push_back(le_fic);
+                }
+            }
         }
-      }
-    }
-  } while((FindNextFile(listing, &wData)));
+    } while((FindNextFile(listing, &wData)));
 
 #else
-  // Fichiers locaux
-  string rep(Constante::GetLocalDir());
-  rep+=Constante::GetTableauDir();
-  rep+='/';
+    // Fichiers locaux
+    string rep(Constante::GetLocalDir());
+    rep+=Constante::GetTableauDir();
+    rep+='/';
   
-  dirent * mon_dirent;
-  DIR * dir=opendir(rep.c_str());
-  if (dir!=NULL)
-  {
-    mon_dirent=readdir(dir);
-    while ( mon_dirent!=NULL )
+    dirent * mon_dirent;
+    DIR * dir=opendir(rep.c_str());
+    if (dir!=NULL)
     {
-      string fichier=rep+mon_dirent->d_name;
-      struct stat stat_fic;
-      stat(fichier.c_str(), &stat_fic);
-      if (S_ISDIR(stat_fic.st_mode) && access(fichier.c_str(),R_OK)==0 && access(fichier.c_str(),X_OK)==0)
-      {
-        string le_rep(mon_dirent->d_name);
-        if (le_rep != ".." && le_rep != ".")
+        mon_dirent=readdir(dir);
+        while ( mon_dirent!=NULL )
         {
-          // C'est un rpertoire, et on peut y accder
-          if (GetListeTableau(le_rep).size() != 0)
-          {
-            preprocList.insert(le_rep);
-          }
+            string fichier=rep+mon_dirent->d_name;
+            struct stat stat_fic;
+            stat(fichier.c_str(), &stat_fic);
+            if (S_ISDIR(stat_fic.st_mode) && access(fichier.c_str(),R_OK)==0 && access(fichier.c_str(),X_OK)==0)
+            {
+                string le_rep(mon_dirent->d_name);
+                if (le_rep != ".." && le_rep != ".")
+                {
+                    // C'est un rpertoire, et on peut y accder
+                    if (GetListeTableau(le_rep).size() != 0)
+                    {
+                        preprocList.insert(le_rep);
+                    }
+                }
+            }
+            mon_dirent=readdir(dir);
         }
-      }
-      mon_dirent=readdir(dir);
-    }
-    for(set<string>::iterator it = preprocList.begin(); it != preprocList.end(); it++)
-    {
-      liste.push_back(GetGroupeTableauDesc(rep, *it));
-      _VectNomGroupe.push_back(*it);      
-    }
-  }
-
-  // Fichiers globals
-  rep=Constante::GetGlobalDir();
-  rep+=Constante::GetTableauDir();
-  rep+='/';
-
-  dir=opendir(rep.c_str());
-  if (dir!=NULL)
-  {
-    mon_dirent=readdir(dir);
-    while (mon_dirent!=NULL)
-    {
-      string fichier=rep+mon_dirent->d_name;
-      struct stat stat_fic;
-      stat(fichier.c_str(), &stat_fic);
-      if (S_ISDIR(stat_fic.st_mode) && access(fichier.c_str(),R_OK)==0 && access(fichier.c_str(),X_OK)==0)
-      {
-        string le_rep(mon_dirent->d_name);
-        if (le_rep != ".." && le_rep != ".")
+        for(set<string>::iterator it = preprocList.begin(); it != preprocList.end(); it++)
         {
-          // C'est un rpertoire, et on peut y accder
-          if (GetListeTableau(le_rep).size() != 0)
-          {
-            preprocList.insert(le_rep);
-          }
+            liste.push_back(GetGroupeTableauDesc(rep, *it));
+            _VectNomGroupe.push_back(*it);      
         }
-      }
-      mon_dirent=readdir(dir);
-    }
-    for(set<string>::iterator it = preprocList.begin(); it != preprocList.end(); it++)
-    {
-      liste.push_back(GetGroupeTableauDesc(rep, *it));
-      _VectNomGroupe.push_back(*it);      
     }
 
-  }
+    // Fichiers globals
+    preprocList.clear();
+    rep=Constante::GetGlobalDir();
+    rep+=Constante::GetTableauDir();
+    rep+='/';
+
+    dir=opendir(rep.c_str());
+    if (dir!=NULL)
+    {
+        mon_dirent=readdir(dir);
+        while (mon_dirent!=NULL)
+        {
+            string fichier=rep+mon_dirent->d_name;
+            struct stat stat_fic;
+            stat(fichier.c_str(), &stat_fic);
+            if (S_ISDIR(stat_fic.st_mode) && access(fichier.c_str(),R_OK)==0 && access(fichier.c_str(),X_OK)==0)
+            {
+                string le_rep(mon_dirent->d_name);
+                if (le_rep != ".." && le_rep != ".")
+                {
+                    // C'est un rpertoire, et on peut y accder
+                    if (GetListeTableau(le_rep).size() != 0)
+                    {
+                        preprocList.insert(le_rep);
+                    }
+                }
+            }
+            mon_dirent=readdir(dir);
+        }
+        for(set<string>::iterator it = preprocList.begin(); it != preprocList.end(); it++)
+        {
+            liste.push_back(GetGroupeTableauDesc(rep, *it));
+            _VectNomGroupe.push_back(*it);      
+        }
+
+    }
 #endif
 
-  return liste;
+    return liste;
 }
 
 set<string> TableauBase::GetListeTableau(const string & p_NomGroupe)
