@@ -36,7 +36,7 @@
 
 TableauJeu::TableauJeu(MOGL_Fenetre * p_Fenetre)
   : TableauBase(p_Fenetre), _ProbaBonus(0.2f), _FinTableau(false), _NombreVie(5),
-    _VibrationX(0), _VibrationY(0)
+    _VibrationX(0), _VibrationY(0), _CummulDep(0)
 {
   Plateau * _Plateau=new Plateau;
   _Plateau->SetPosition(20, 1);
@@ -94,36 +94,39 @@ TableauJeu::~TableauJeu()
 
 void TableauJeu::DepartTableau()
 {
-  _Camera->SetVueSubjective(false);
-  for(Set_Balle::iterator itBa=_SetBalle.begin(); itBa!=_SetBalle.end(); itBa++)
-  {
-    _Univers->RetirerElement((*itBa)->GetElementArbreMOGL());
-    delete (*itBa);
-  }
-  _SetBalle.clear();
+    _Camera->SetVueSubjective(false);
+    for(Set_Balle::iterator itBa=_SetBalle.begin(); itBa!=_SetBalle.end(); itBa++)
+    {
+        _Univers->RetirerElement((*itBa)->GetElementArbreMOGL());
+        delete (*itBa);
+    }
+    _SetBalle.clear();
 
-  for(Set_Plateau::iterator itPla=_SetPlateau.begin(); itPla!=_SetPlateau.end(); itPla++)
-  {
-    (*itPla)->SetTaille(5);
-  }
+    for(Set_Plateau::iterator itPla=_SetPlateau.begin(); itPla!=_SetPlateau.end(); itPla++)
+    {
+        (*itPla)->SetPosition(20, 1);
 
-  if (_NombreVie>=0)
-  {
-    ElementTableau::SetDerniereCollision(NULL, NULL);
-    Balle * balle=new Balle;
-    balle->SetTaille(1.5);
-    AjouterBalle(balle);
-    _BallePartie=false;
-    _TemporisationDepartBalle->Demarrer();
+        (*itPla)->SetTaille(5);
+    }
 
-    balle->SetPosition((*_SetPlateau.begin())->GetPositionX(),
-                       (*_SetPlateau.begin())->GetPositionY() + (*_SetPlateau.begin())->GetTailleY()/2 + balle->GetRayon());
-  }
-  else
-  {
-    FinBalle.Emettre();
-  }
-    
+    if (_NombreVie>=0)
+    {
+        ElementTableau::SetDerniereCollision(NULL, NULL);
+        Balle * balle=new Balle;
+        balle->SetTaille(1.5);
+        AjouterBalle(balle);
+        _BallePartie=false;
+        _TemporisationDepartBalle->Demarrer();
+
+        balle->SetPosition((*_SetPlateau.begin())->GetPositionX(),
+                           (*_SetPlateau.begin())->GetPositionY() + (*_SetPlateau.begin())->GetTailleY()/2 + balle->GetRayon());
+    }
+    else
+    {
+        FinBalle.Emettre();
+    }
+    // RAZ du cumul de dplacement
+    _CummulDep = 0;  
 }
 
 void TableauJeu::AjouterBalle(Balle * p_Balle)
@@ -248,7 +251,7 @@ void TableauJeu::Maj()
       {
         (*itBalle)->SetTempsMax(remainingTime);
         // #######################
-        // ## On regarde tous les trucs sur lesquels il peut y avoir collicion
+        // ## On regarde tous les trucs sur lesquels il peut y avoir collision
         // #######################
         Struct_Collision collision, collisionTemps;
 
@@ -302,7 +305,14 @@ void TableauJeu::Maj()
         // Parmis les diffrentes collisions on regarde cel
         // #######################
         
+        // MAJ vitesse dplacement des plateaux selon le dplacement
+        // cumul
+        DeplacerPlateaux(_CummulDep);
+        // RAZ du cumul de dplacement
+        _CummulDep = 0;
+
         // On dplace les plateaux
+
         for(Set_Plateau::iterator itPlat=_SetPlateau.begin(); itPlat!=_SetPlateau.end(); itPlat++)
         {
           (*itPlat)->Deplacer(collision.TempsCollision);
@@ -625,7 +635,7 @@ void TableauJeu::ClavierDown(SDL_keysym * key)
 
     case SDLK_LEFT :
     {
-      DeplacerPlateaux(MOGL_Temps::GetVariationDistance(Option::VitesseClavier.GetValeur() * -10));
+      _CummulDep = MOGL_Temps::GetVariationDistance(Option::VitesseClavier.GetValeur() * -10);
       if (!_BallePartie)
       {
         for(Set_Balle::iterator it=_SetBalle.begin(); it!=_SetBalle.end(); it++)
@@ -638,7 +648,7 @@ void TableauJeu::ClavierDown(SDL_keysym * key)
     }
     case SDLK_RIGHT :
     {
-      DeplacerPlateaux(MOGL_Temps::GetVariationDistance(Option::VitesseClavier.GetValeur() * 10));
+      _CummulDep = MOGL_Temps::GetVariationDistance(Option::VitesseClavier.GetValeur() * 10);
       if (!_BallePartie)
       {
         for(Set_Balle::iterator it=_SetBalle.begin(); it!=_SetBalle.end(); it++)
@@ -656,16 +666,26 @@ void TableauJeu::ClavierDown(SDL_keysym * key)
 
 void TableauJeu::DeplacementSouris(SDL_MouseMotionEvent * p_Event)
 {
-  int val=p_Event->xrel;
-  DeplacerPlateaux(val * Option::VitesseSouris.GetValeur()/50.0);
-  if (!_BallePartie)
-  {
-    for(Set_Balle::iterator it=_SetBalle.begin(); it!=_SetBalle.end(); it++)
+    static bool bNotFirstDep = false;
+    if (bNotFirstDep)
     {
-      (*it)->SetPosition((*_SetPlateau.begin())->GetPositionX(),
-                         (*_SetPlateau.begin())->GetPositionY() + (*_SetPlateau.begin())->GetTailleY()/2 + (*it)->GetRayon());
+        int val=p_Event->xrel;
+        _CummulDep += val * Option::VitesseSouris.GetValeur()/50.0;
+    }
+    else
+    {
+        bNotFirstDep = true;
+        _CummulDep = 0;
+    }
+    if (!_BallePartie)
+    {
+        for(Set_Balle::iterator it=_SetBalle.begin(); it!=_SetBalle.end(); it++)
+        {
+            (*it)->SetPosition((*_SetPlateau.begin())->GetPositionX(),
+                               (*_SetPlateau.begin())->GetPositionY() + 
+                               (*_SetPlateau.begin())->GetTailleY()/2 + (*it)->GetRayon());
+        }
     }
-  }
 }
 
 void TableauJeu::_OnFinTemporisation()
